package List::Util::Null;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-07-05'; # DATE
our $DIST = 'List-AllUtils-Null'; # DIST
our $VERSION = '0.004'; # VERSION

use alias::module 'List::AllUtils::Null';

1;
# ABSTRACT: Alias for List::AllUtils::Null

__END__

=pod

=encoding UTF-8

=head1 NAME

List::Util::Null - Alias for List::AllUtils::Null

=head1 VERSION

This document describes version 0.004 of List::Util::Null (from Perl distribution List-AllUtils-Null), released on 2021-07-05.

=head1 SYNOPSIS

Use L<List::AllUtils::Null> instead.

=for Pod::Coverage ^(.+)$

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/List-AllUtils-Null>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-List-AllUtils-Null>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=List-AllUtils-Null>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<List::AllUtils::Null>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
